import sys

from .rrpm import cli

if __name__ == "__main__":
    sys.exit(cli())
